% Auto-generated chapter 6 for tirmidhi
% Hadiths in this chapter: 73

\hadithdefcmd{tirmidhi}{544}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْحَكَمِ الْوَرَّاقُ الْبَغْدَادِيُّ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ سَافَرْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ فَكَانُوا يُصَلُّونَ الظُّهْرَ وَالْعَصْرَ رَكْعَتَيْنِ رَكْعَتَيْنِ لاَ يُصَلُّونَ قَبْلَهَا وَلاَ بَعْدَهَا ‏.‏ وَقَالَ عَبْدُ اللَّهِ لَوْ كُنْتُ مُصَلِّيًا قَبْلَهَا أَوْ بَعْدَهَا لأَتْمَمْتُهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَعَلِيٍّ وَابْنِ عَبَّاسٍ وَأَنَسٍ وَعِمْرَانَ بْنِ حُصَيْنٍ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ يَحْيَى بْنِ سُلَيْمٍ مِثْلَ هَذَا ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ عَنْ رَجُلٍ مِنْ آلِ سُرَاقَةَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ عَنْ عَطِيَّةَ الْعَوْفِيِّ عَنِ ابْنِ عُمَرَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَطَوَّعُ فِي السَّفَرِ قَبْلَ الصَّلاَةِ وَبَعْدَهَا ‏.‏ وَقَدْ صَحَّ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقْصُرُ فِي السَّفَرِ وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ صَدْرًا مِنْ خِلاَفَتِهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ‏.‏ وَقَدْ رُوِيَ عَنْ عَائِشَةَ أَنَّهَا كَانَتْ تُتِمُّ الصَّلاَةَ فِي السَّفَرِ ‏.‏ وَالْعَمَلُ عَلَى مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَأَصْحَابِهِ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ إِلاَّ أَنَّ الشَّافِعِيَّ يَقُولُ التَّقْصِيرُ رُخْصَةٌ لَهُ فِي السَّفَرِ فَإِنْ أَتَمَّ الصَّلاَةَ أَجْزَأَ عَنْهُ ‏.‏\hadithno{544}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Umar narrated:"I traveled with the Prophet, Abu Bakr, Umar, and Uthman; they would pray Zuhr and Asr as two Rak'ah and two Rak'ah, not praying before them nor after them." And Ibn Umar said: "If I was going to pray before it or after it then I would pray it complete}}
\hadithdefcmd{tirmidhi}{545}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا عَلِيُّ بْنُ زَيْدِ بْنِ جُدْعَانَ الْقُرَشِيُّ، عَنْ أَبِي نَضْرَةَ، قَالَ سُئِلَ عِمْرَانُ بْنُ حُصَيْنٍ عَنْ صَلاَةِ الْمُسَافِرِ، فَقَالَ حَجَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى رَكْعَتَيْنِ وَحَجَجْتُ مَعَ أَبِي بَكْرٍ فَصَلَّى رَكْعَتَيْنِ وَمَعَ عُمَرَ فَصَلَّى رَكْعَتَيْنِ وَمَعَ عُثْمَانَ سِتَّ سِنِينَ مِنْ خِلاَفَتِهِ أَوْ ثَمَانِيَ سِنِينَ فَصَلَّى رَكْعَتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{545}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu An-Nadrah said:"Imran bin Husain was asked about the traveler's prayer. He said: 'I performed Hajj with the Messenger of Allah, and he prayed two Rak'ah. I performed Hajj with Abu Bakr, and he prayed two Rak'ah and with Umar, and he prayed two Rak;ah; and with Uthman for six years of his Khilafah, or eight years, and he prayed two Rak'ah}}
\hadithdefcmd{tirmidhi}{546}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، وَإِبْرَاهِيمَ بْنِ مَيْسَرَةَ، سَمِعَا أَنَسَ بْنَ مَالِكٍ، قَالَ صَلَّيْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم الظُّهْرَ بِالْمَدِينَةِ أَرْبَعًا وَبِذِي الْحُلَيْفَةِ الْعَصْرَ رَكْعَتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{546}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated:"We prayed Zuhr as four with the Prophet in Al-Madinah, and Asr as two Rak'ah in Dhil-Hulaifah}}
\hadithdefcmd{tirmidhi}{547}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا هُشَيْمٌ، عَنْ مَنْصُورِ بْنِ زَاذَانَ، عَنِ ابْنِ سِيرِينَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ مِنَ الْمَدِينَةِ إِلَى مَكَّةَ لاَ يَخَافُ إِلاَّ اللَّهَ رَبَّ الْعَالَمِينَ فَصَلَّى رَكْعَتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{547}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"The Prophet went from Al-Madinah to Makkah, not fearing anyone except Allah the Lord of the worlds, and he prayed two Rak'ah}}
\hadithdefcmd{tirmidhi}{548}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ الْحَضْرَمِيُّ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم مِنَ الْمَدِينَةِ إِلَى مَكَّةَ فَصَلَّى رَكْعَتَيْنِ ‏.‏ قَالَ قُلْتُ لأَنَسٍ كَمْ أَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَكَّةَ قَالَ عَشْرًا ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ أَقَامَ فِي بَعْضِ أَسْفَارِهِ تِسْعَ عَشْرَةَ يُصَلِّي رَكْعَتَيْنِ ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَنَحْنُ إِذَا أَقَمْنَا مَا بَيْنَنَا وَبَيْنَ تِسْعَ عَشْرَةَ صَلَّيْنَا رَكْعَتَيْنِ وَإِنْ زِدْنَا عَلَى ذَلِكَ أَتْمَمْنَا الصَّلاَةَ ‏.‏ وَرُوِيَ عَنْ عَلِيٍّ أَنَّهُ قَالَ مَنْ أَقَامَ عَشَرَةَ أَيَّامٍ أَتَمَّ الصَّلاَةَ ‏.‏ وَرُوِيَ عَنِ ابْنِ عُمَرَ أَنَّهُ قَالَ مَنْ أَقَامَ خَمْسَةَ عَشَرَ يَوْمًا أَتَمَّ الصَّلاَةَ ‏.‏ وَقَدْ رُوِيَ عَنْهُ ثِنْتَىْ عَشْرَةَ ‏.‏ وَرُوِيَ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ أَنَّهُ قَالَ إِذَا أَقَامَ أَرْبَعًا صَلَّى أَرْبَعًا ‏.‏ وَرَوَى عَنْهُ ذَلِكَ قَتَادَةُ وَعَطَاءٌ الْخُرَاسَانِيُّ ‏.‏ وَرَوَى عَنْهُ دَاوُدُ بْنُ أَبِي هِنْدٍ خِلاَفَ هَذَا ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ بَعْدُ فِي ذَلِكَ فَأَمَّا سُفْيَانُ الثَّوْرِيُّ وَأَهْلُ الْكُوفَةِ فَذَهَبُوا إِلَى تَوْقِيتِ خَمْسَ عَشْرَةَ وَقَالُوا إِذَا أَجْمَعَ عَلَى إِقَامَةِ خَمْسَ عَشْرَةَ أَتَمَّ الصَّلاَةَ ‏.‏ وَقَالَ الأَوْزَاعِيُّ إِذَا أَجْمَعَ عَلَى إِقَامَةِ ثِنْتَىْ عَشْرَةَ أَتَمَّ الصَّلاَةَ ‏.‏ وَقَالَ مَالِكُ بْنُ أَنَسٍ وَالشَّافِعِيُّ وَأَحْمَدُ إِذَا أَجْمَعَ عَلَى إِقَامَةِ أَرْبَعَةٍ أَتَمَّ الصَّلاَةَ ‏.‏ وَأَمَّا إِسْحَاقُ فَرَأَى أَقْوَى الْمَذَاهِبِ فِيهِ حَدِيثَ ابْنِ عَبَّاسٍ قَالَ لأَنَّهُ رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم ثُمَّ تَأَوَّلَهُ بَعْدَ النَّبِيِّ صلى الله عليه وسلم إِذَا أَجْمَعَ عَلَى إِقَامَةِ تِسْعَ عَشْرَةَ أَتَمَّ الصَّلاَةَ ‏.‏ ثُمَّ أَجْمَعَ أَهْلُ الْعِلْمِ عَلَى أَنَّ الْمُسَافِرَ يَقْصُرُ مَا لَمْ يُجْمِعْ إِقَامَةً وَإِنْ أَتَى عَلَيْهِ سِنُونَ ‏.‏\hadithno{548}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Yahya bin Abi Ishaq Al-Hadrami narrated :that Anas bin Malik said: "We went with the Messenger of Allah from Al-Madinah to Makkah, and he prayed two Rak'ah." He said: "I said to Anas: 'How long did Messenger of Allah stay in Makkah?' He said: 'Ten (days)}}
\hadithdefcmd{tirmidhi}{549}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَافَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَفَرًا فَصَلَّى تِسْعَةَ عَشَرَ يَوْمًا رَكْعَتَيْنِ رَكْعَتَيْنٍ ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَنَحْنُ نُصَلِّي فِيمَا بَيْنَنَا وَبَيْنَ تِسْعَ عَشْرَةَ رَكْعَتَيْنِ رَكْعَتَيْنِ فَإِذَا أَقَمْنَا أَكْثَرَ مِنْ ذَلِكَ صَلَّيْنَا أَرْبَعًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{549}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Abbas narrated:"The Messenger of Allah traveled on a journey and he prayed two Rak'ah for nineteen days." Ibn Abbas said: "So when we would stay somewhere for nineteen (days) we would pray two Rak'ah , and if we stayed longer than that we would complete the Salat}}
\hadithdefcmd{tirmidhi}{550}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ أَبِي بُسْرَةَ الْغِفَارِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ صَحِبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ثَمَانِيَةَ عَشَرَ سَفَرًا فَمَا رَأَيْتُهُ تَرَكَ الرَّكْعَتَيْنِ إِذَا زَاغَتِ الشَّمْسُ قَبْلَ الظُّهْرِ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْبَرَاءِ حَدِيثٌ غَرِيبٌ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدًا عَنْهُ فَلَمْ يَعْرِفْهُ إِلاَّ مِنْ حَدِيثِ اللَّيْثِ بْنِ سَعْدٍ وَلَمْ يَعْرِفِ اسْمَ أَبِي بُسْرَةَ الْغِفَارِيِّ وَرَآهُ حَسَنًا ‏.‏ وَرُوِيَ عَنِ ابْنِ عُمَرَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَتَطَوَّعُ فِي السَّفَرِ قَبْلَ الصَّلاَةِ وَلاَ بَعْدَهَا ‏.‏ وَرُوِيَ عَنْهُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَتَطَوَّعُ فِي السَّفَرِ ‏.‏ ثُمَّ اخْتَلَفَ أَهْلُ الْعِلْمِ بَعْدَ النَّبِيِّ صلى الله عليه وسلم فَرَأَى بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنْ يَتَطَوَّعَ الرَّجُلُ فِي السَّفَرِ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَلَمْ تَرَ طَائِفَةٌ مِنْ أَهْلِ الْعِلْمِ أَنْ يُصَلَّى قَبْلَهَا وَلاَ بَعْدَهَا ‏.‏ وَمَعْنَى مَنْ لَمْ يَتَطَوَّعْ فِي السَّفَرِ قَبُولُ الرُّخْصَةِ وَمَنْ تَطَوَّعَ فَلَهُ فِي ذَلِكَ فَضْلٌ كَثِيرٌ ‏.‏ وَهُوَ قَوْلُ أَكْثَرِ أَهْلِ الْعِلْمِ يَخْتَارُونَ التَّطَوُّعَ فِي السَّفَرِ ‏.‏\hadithno{550}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Al-Bara bin Azib said:"I accompanied the Messenger of Allah on eighteen journeys, and I did not see him leave the two Rak'ah when the sun waned before Zuhr}}
\hadithdefcmd{tirmidhi}{551}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الْحَجَّاجِ، عَنْ عَطِيَّةَ، عَنِ ابْنِ عُمَرَ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم الظُّهْرَ فِي السَّفَرِ رَكْعَتَيْنِ وَبَعْدَهَا رَكْعَتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَاهُ ابْنُ أَبِي لَيْلَى عَنْ عَطِيَّةَ وَنَافِعٍ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{551}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated:"I prayed Zuhr with the Prophet on a journey as two Rak'ah, and two Rak'ah after it}}
\hadithdefcmd{tirmidhi}{552}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْمُحَارِبِيُّ، - يَعْنِي الْكُوفِيَّ حَدَّثَنَا عَلِيُّ بْنُ هَاشِمٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَطِيَّةَ، وَنَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي الْحَضَرِ وَالسَّفَرِ فَصَلَّيْتُ مَعَهُ فِي الْحَضَرِ الظُّهْرَ أَرْبَعًا وَبَعْدَهَا رَكْعَتَيْنِ وَصَلَّيْتُ مَعَهُ فِي السَّفَرِ الظُّهْرَ رَكْعَتَيْنِ وَبَعْدَهَا رَكْعَتَيْنِ وَالْعَصْرَ رَكْعَتَيْنِ وَلَمْ يُصَلِّ بَعْدَهَا شَيْئًا وَالْمَغْرِبَ فِي الْحَضَرِ وَالسَّفَرِ سَوَاءً ثَلاَثَ رَكَعَاتٍ لاَ تَنْقُصُ فِي الْحَضَرِ وَلاَ فِي السَّفَرِ وَهِيَ وِتْرُ النَّهَارِ وَبَعْدَهَا رَكْعَتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ سَمِعْتُ مُحَمَّدًا يَقُولُ مَا رَوَى ابْنُ أَبِي لَيْلَى حَدِيثًا أَعْجَبَ إِلَىَّ مِنْ هَذَا وَلاَ أَرْوِي عَنْهُ شَيْئًا ‏.‏\hadithno{552}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated:"I prayed with the Prophet both, while a resident and while traveling. So I prayed four for Zuhr with him as a resident, and two Rak'ah after it. I prayed two Rak'ah for Zuhr with him while traveling and two Rak'ah after it, and two Rak'ah for Asr, and he did not pray anything after it. Maghrib while a resident and traveling is the same; three Rak'ah, it is not decreased as a resident nor while traveling. It is Witr of the day, and after it are two Rak'ah}}
\hadithdefcmd{tirmidhi}{553}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الطُّفَيْلِ، هُوَ عَامِرُ بْنُ وَاثِلَةَ عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ فِي غَزْوَةِ تَبُوكَ إِذَا ارْتَحَلَ قَبْلَ زَيْغِ الشَّمْسِ أَخَّرَ الظُّهْرَ إِلَى أَنْ يَجْمَعَهَا إِلَى الْعَصْرِ فَيُصَلِّيهِمَا جَمِيعًا وَإِذَا ارْتَحَلَ بَعْدَ زَيْغِ الشَّمْسِ عَجَّلَ الْعَصْرَ إِلَى الظُّهْرِ وَصَلَّى الظُّهْرَ وَالْعَصْرَ جَمِيعًا ثُمَّ سَارَ وَكَانَ إِذَا ارْتَحَلَ قَبْلَ الْمَغْرِبِ أَخَّرَ الْمَغْرِبَ حَتَّى يُصَلِّيَهَا مَعَ الْعِشَاءِ وَإِذَا ارْتَحَلَ بَعْدَ الْمَغْرِبِ عَجَّلَ الْعِشَاءَ فَصَلاَّهَا مَعَ الْمَغْرِبِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ عُمَرَ وَأَنَسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَائِشَةَ وَابْنِ عَبَّاسٍ وَأُسَامَةَ بْنِ زَيْدٍ وَجَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى وَالصَّحِيحُ عَنْ أُسَامَةَ ‏.‏ وَرَوَى عَلِيُّ بْنُ الْمَدِينِيِّ عَنْ أَحْمَدَ بْنِ حَنْبَلٍ عَنْ قُتَيْبَةَ هَذَا الْحَدِيثَ ‏.‏\hadithno{553}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mu'adh bin Jabal narrated:"While the Prophet as at the Battle of Tabuk, if he wanted to depart before the sun's decline he would delay Zuhr so that he could pray it together with Asr. If he wanted to depart after the sun's decline, he would hasten Asr to Zuhr, and pray Zuhr and Asr together, and then move it. If he wanted to depart before Maghrib he would delay Maghrib until he prayed it with Isha, and if he wanted to depart after Maghrib he would hasten Isha so that he would pray it along with Maghrib}}
\hadithdefcmd{tirmidhi}{554}{حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ سُلَيْمَانَ، حَدَّثَنَا زَكَرِيَّا اللُّؤْلُؤِيُّ، حَدَّثَنَا أَبُو بَكْرٍ الأَعْيَنُ، حَدَّثَنَا عَلِيُّ بْنُ الْمَدِينِيِّ، حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا قُتَيْبَةُ، بِهَذَا الْحَدِيثِ يَعْنِي حَدِيثَ مُعَاذٍ ‏.‏ وَحَدِيثُ مُعَاذٍ حَدِيثٌ حَسَنٌ غَرِيبٌ تَفَرَّدَ بِهِ قُتَيْبَةُ لاَ نَعْرِفُ أَحَدًا رَوَاهُ عَنِ اللَّيْثِ غَيْرَهُ ‏.‏ وَحَدِيثُ اللَّيْثِ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ عَنْ أَبِي الطُّفَيْلِ عَنْ مُعَاذٍ حَدِيثٌ غَرِيبٌ ‏.‏ وَالْمَعْرُوفُ عِنْدَ أَهْلِ الْعِلْمِ حَدِيثُ مُعَاذٍ مِنْ حَدِيثِ أَبِي الزُّبَيْرِ عَنْ أَبِي الطُّفَيْلِ عَنْ مُعَاذٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم جَمَعَ فِي غَزْوَةِ تَبُوكَ بَيْنَ الظُّهْرِ وَالْعَصْرِ وَبَيْنَ الْمَغْرِبِ وَالْعِشَاءِ ‏.‏ رَوَاهُ قُرَّةُ بْنُ خَالِدٍ وَسُفْيَانُ الثَّوْرِيُّ وَمَالِكٌ وَغَيْرُ وَاحِدٍ عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ ‏.‏ وَبِهَذَا الْحَدِيثِ يَقُولُ الشَّافِعِيُّ ‏.‏ وَأَحْمَدُ وَإِسْحَاقُ يَقُولاَنِ لاَ بَأْسَ أَنْ يَجْمَعَ بَيْنَ الصَّلاَتَيْنِ فِي السَّفَرِ فِي وَقْتِ إِحْدَاهُمَا ‏.‏\hadithno{554}\hadithgrade{Zubair Ali Zai: Isnaad Sahih}\hadithtrans{(Another chain) Qutaibah narrated :this Hadith to us, meaning the Hadith of Mu'adh}}
\hadithdefcmd{tirmidhi}{555}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ اسْتُغِيثَ عَلَى بَعْضِ أَهْلِهِ فَجَدَّ بِهِ السَّيْرُ فَأَخَّرَ الْمَغْرِبَ حَتَّى غَابَ الشَّفَقُ ثُمَّ نَزَلَ فَجَمَعَ بَيْنَهُمَا ثُمَّ أَخْبَرَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَفْعَلُ ذَلِكَ إِذَا جَدَّ بِهِ السَّيْرُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَحَدِيثُ اللَّيْثِ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{555}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Nafi narrated:"Ibn Umar had been requested to urgently attend to one of his wives, so he hurried en route and delayed Maghrib until the twilight disappeared, then he dismounted to combine them (the prayers). Then he informed them that the Messenger of Allah would do that when he was in a hurry on a trip}}
\hadithdefcmd{tirmidhi}{556}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ بِالنَّاسِ يَسْتَسْقِي فَصَلَّى بِهِمْ رَكْعَتَيْنِ جَهَرَ بِالْقِرَاءَةِ فِيهِمَا وَحَوَّلَ رِدَاءَهُ وَرَفَعَ يَدَيْهِ وَاسْتَسْقَى وَاسْتَقْبَلَ الْقِبْلَةَ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَأَنَسٍ وَآبِي اللَّحْمِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ زَيْدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَلَى هَذَا الْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَعَمُّ عَبَّادِ بْنِ تَمِيمٍ هُوَ عَبْدُ اللَّهِ بْنُ زَيْدِ بْنِ عَاصِمٍ الْمَازِنِيُّ ‏.‏\hadithno{556}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abbad bin Tamim narrated from his uncle:"The Messenger of Allah went out with the people to seek rain. So he led them in prayer for two Rak'ah, reciting aloud in them, turning his upper wrap around, raising his hands, requesting rain, and facing the Qiblah}}
\hadithdefcmd{tirmidhi}{557}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، عَنْ عُمَيْرٍ، مَوْلَى آبِي اللَّحْمِ عَنْ آبِي اللَّحْمِ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم عِنْدَ أَحْجَارِ الزَّيْتِ يَسْتَسْقِي وَهُوَ مُقْنِعٌ بِكَفَّيْهِ يَدْعُو ‏.‏ قَالَ أَبُو عِيسَى كَذَا قَالَ قُتَيْبَةُ فِي هَذَا الْحَدِيثِ عَنْ آبِي اللَّحْمِ وَلاَ نَعْرِفُ لَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ هَذَا الْحَدِيثَ الْوَاحِدَ وَعُمَيْرٌ مَوْلَى آبِي اللَّحْمِ قَدْ رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم أَحَادِيثَ وَلَهُ صُحْبَةٌ ‏.‏\hadithno{557}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umair, the freed slave of Abi Al-Lahm narrated from Abi Al-Lahm that :he saw the Messenger of Allah at Ahjar Az-Zait, supplicating for rain, and he was raising his hands in supplication}}
\hadithdefcmd{tirmidhi}{558}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ هِشَامِ بْنِ إِسْحَاقَ، وَهُوَ ابْنُ عَبْدِ اللَّهِ بْنِ كِنَانَةَ عَنْ أَبِيهِ، قَالَ أَرْسَلَنِي الْوَلِيدُ بْنُ عُقْبَةَ وَهُوَ أَمِيرُ الْمَدِينَةِ إِلَى ابْنِ عَبَّاسٍ أَسْأَلُهُ عَنِ اسْتِسْقَاءِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَتَيْتُهُ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ مُتَبَذِّلاً مُتَوَاضِعًا مُتَضَرِّعًا حَتَّى أَتَى الْمُصَلَّى فَلَمْ يَخْطُبْ خُطْبَتَكُمْ هَذِهِ وَلَكِنْ لَمْ يَزَلْ فِي الدُّعَاءِ وَالتَّضَرُّعِ وَالتَّكْبِيرِ وَصَلَّى رَكْعَتَيْنِ كَمَا كَانَ يُصَلِّي فِي الْعِيدِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{558}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It is narrated from Hisham bin Ishaq - and he was from Ibn Abdullah bin Kinanah - from his father who said:"Al-Walid bin Uqbah, the governor of Al-Madinah, sent me to ask Ibn Abbas about how the Messenger of Allah would perform Salat Al-Istisqa. I came to him and he said: 'The Messenger of Allah would go out in modest dress, humbly, imploring, until he reached the Musalla. He would not give this Khutbah of yours, rather, he would continue supplication and imploring saying the Takbir, and pray two Rak'ah, just as he would pray for the Eid}}
\hadithdefcmd{tirmidhi}{559}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ هِشَامِ بْنِ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ كِنَانَةَ، عَنْ أَبِيهِ، فَذَكَرَ نَحْوَهُ وَزَادَ فِيهِ مُتَخَشِّعًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ قَالَ يُصَلِّي صَلاَةَ الاِسْتِسْقَاءِ نَحْوَ صَلاَةِ الْعِيدَيْنِ يُكَبِّرُ فِي الرَّكْعَةِ الأُولَى سَبْعًا وَفِي الثَّانِيَةِ خَمْسًا وَاحْتَجَّ بِحَدِيثِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى وَرُوِيَ عَنْ مَالِكِ بْنِ أَنَسٍ أَنَّهُ قَالَ لاَ يُكَبِّرُ فِي صَلاَةِ الاِسْتِسْقَاءِ كَمَا يُكَبِّرُ فِي صَلاَةِ الْعِيدَيْنِ ‏.‏ وَقَالَ النُّعْمَانُ أَبُو حَنِيفَةَ لاَ تُصَلَّى صَلاَةُ الاِسْتِسْقَاءِ وَلاَ آمُرُهُمْ بِتَحْوِيلِ الرِّدَاءِ وَلَكِنْ يَدْعُونَ وَيَرْجِعُونَ بِجُمْلَتِهِمْ ‏.‏ قَالَ أَبُو عِيسَى خَالَفَ السُّنَّةَ ‏.‏\hadithno{559}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{(Another chain) from Hisham bin Ishaq bin Abdullah bin Kinanah, from his father, :and he mentioned a similar narration and added: "with humility" to it}}
\hadithdefcmd{tirmidhi}{560}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى فِي كُسُوفٍ فَقَرَأَ ثُمَّ رَكَعَ ثُمَّ قَرَأَ ثُمَّ رَكَعَ ثُمَّ قَرَأَ ثُمَّ رَكَعَ ثَلاَثَ مَرَّاتٍ ثُمَّ سَجَدَ سَجْدَتَيْنِ وَالأُخْرَى مِثْلُهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَائِشَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَالنُّعْمَانِ بْنِ بَشِيرٍ وَالْمُغِيرَةِ بْنِ شُعْبَةَ وَأَبِي مَسْعُودٍ وَأَبِي بَكْرَةَ وَسَمُرَةَ وَأَبِي مُوسَى الأَشْعَرِيِّ وَابْنِ مَسْعُودٍ وَأَسْمَاءَ بِنْتِ أَبِي بَكْرٍ الصِّدِّيقِ وَابْنِ عُمَرَ وَقَبِيصَةَ الْهِلاَلِيِّ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَعَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ وَأُبَىِّ بْنِ كَعْبٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى فِي كُسُوفٍ أَرْبَعَ رَكَعَاتٍ فِي أَرْبَعِ سَجَدَاتٍ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ قَالَ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْقِرَاءَةِ فِي صَلاَةِ الْكُسُوفِ فَرَأَى بَعْضُ أَهْلِ الْعِلْمِ أَنْ يُسِرَّ بِالْقِرَاءَةِ فِيهَا بِالنَّهَارِ ‏.‏ وَرَأَى بَعْضُهُمْ أَنْ يَجْهَرَ بِالْقِرَاءَةِ فِيهَا كَنَحْوِ صَلاَةِ الْعِيدَيْنِ وَالْجُمُعَةِ وَبِهِ يَقُولُ مَالِكٌ وَأَحْمَدُ وَإِسْحَاقُ يَرَوْنَ الْجَهْرَ فِيهَا ‏.‏ وَقَالَ الشَّافِعِيُّ لاَ يَجْهَرُ فِيهَا ‏.‏ وَقَدْ صَحَّ عَنِ النَّبِيِّ صلى الله عليه وسلم كِلْتَا الرِّوَايَتَيْنِ صَحَّ عَنْهُ أَنَّهُ صَلَّى أَرْبَعَ رَكَعَاتٍ فِي أَرْبَعِ سَجَدَاتٍ ‏.‏ وَصَحَّ عَنْهُ أَيْضًا أَنَّهُ صَلَّى سِتَّ رَكَعَاتٍ فِي أَرْبَعِ سَجَدَاتٍ ‏.‏ وَهَذَا عِنْدَ أَهْلِ الْعِلْمِ جَائِزٌ عَلَى قَدْرِ الْكُسُوفِ إِنْ تَطَاوَلَ الْكُسُوفُ فَصَلَّى سِتَّ رَكَعَاتٍ فِي أَرْبَعِ سَجَدَاتٍ فَهُوَ جَائِزٌ وَإِنْ صَلَّى أَرْبَعَ رَكَعَاتٍ فِي أَرْبَعِ سَجَدَاتٍ وَأَطَالَ الْقِرَاءَةَ فَهُوَ جَائِزٌ ‏.‏ وَيَرَوْنَ أَصْحَابُنَا أَنْ تُصَلَّى صَلاَةُ الْكُسُوفَ فِي جَمَاعَةٍ فِي كُسُوفِ الشَّمْسِ وَالْقَمَرِ ‏.‏\hadithno{560}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Ibn Abbas narrated:"The Prophet prayed during the eclipse. He recited, then bowed, then recited, then bowed, then recited, then bowed. (three times), then he performed two prostrations, and the next one (Rak'ah) was the same}}
\hadithdefcmd{tirmidhi}{561}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ خَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالنَّاسِ فَأَطَالَ الْقِرَاءَةَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ رَأْسَهُ فَأَطَالَ الْقِرَاءَةَ وَهِيَ دُونَ الأُولَى ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ وَهُوَ دُونَ الأَوَّلِ ثُمَّ رَفَعَ رَأْسَهُ فَسَجَدَ ثُمَّ فَعَلَ مِثْلَ ذَلِكَ فِي الرَّكْعَةِ الثَّانِيَةِ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَبِهَذَا الْحَدِيثِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ يَرَوْنَ صَلاَةَ الْكُسُوفِ أَرْبَعَ رَكَعَاتٍ فِي أَرْبَعِ سَجَدَاتٍ ‏.‏ قَالَ الشَّافِعِيُّ يَقْرَأُ فِي الرَّكْعَةِ الأُولَى بِأُمِّ الْقُرْآنِ وَنَحْوًا مِنْ سُورَةِ الْبَقَرَةِ سِرًّا إِنْ كَانَ بِالنَّهَارِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً نَحْوًا مِنْ قِرَاءَتِهِ ثُمَّ رَفَعَ رَأْسَهُ بِتَكْبِيرٍ وَثَبَتَ قَائِمًا كَمَا هُوَ وَقَرَأَ أَيْضًا بِأُمِّ الْقُرْآنِ وَنَحْوًا مِنْ آلِ عِمْرَانَ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً نَحْوًا مِنْ قِرَاءَتِهِ ثُمَّ رَفَعَ رَأْسَهُ ثُمَّ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ ثُمَّ سَجَدَ سَجْدَتَيْنِ تَامَّتَيْنِ وَيُقِيمُ فِي كُلِّ سَجْدَةٍ نَحْوًا مِمَّا أَقَامَ فِي رُكُوعِهِ ثُمَّ قَامَ فَقَرَأَ بِأُمِّ الْقُرْآنِ وَنَحْوًا مِنْ سُورَةِ النِّسَاءِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً نَحْوًا مِنْ قِرَاءَتِهِ ثُمَّ رَفَعَ رَأْسَهُ بِتَكْبِيرٍ وَثَبَتَ قَائِمًا ثُمَّ قَرَأَ نَحْوًا مِنْ سُورَةِ الْمَائِدَةِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً نَحْوًا مِنْ قِرَاءَتِهِ ثُمَّ رَفَعَ فَقَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ ثُمَّ سَجَدَ سَجْدَتَيْنِ ثُمَّ تَشَهَّدَ وَسَلَّمَ ‏.‏\hadithno{561}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"The sun was eclipsed during the time of the Messenger of Allah, so the Messenger of Allah led the people in prayer. He recited a lengthy recitation, then he bowed a lengthy bowing, then he raised his head and recited a lengthy recitation that was less than the first. Then he bowed a lengthy bowing that was less than the first. Then he raised his head and prostrated. Then he did (similar to) that in the second Rak'ah}}
\hadithdefcmd{tirmidhi}{562}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ ثَعْلَبَةَ بْنِ عِبَادٍ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ صَلَّى بِنَا النَّبِيُّ صلى الله عليه وسلم فِي كُسُوفٍ لاَ نَسْمَعُ لَهُ صَوْتًا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَمُرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{562}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Samurah bin Jundah narrated:"The Prophet led us in prayer during an eclipse; we did not hear his voice}}
\hadithdefcmd{tirmidhi}{563}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ أَبَانَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ صَدَقَةَ، عَنْ سُفْيَانَ بْنِ حُسَيْنٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى صَلاَةَ الْكُسُوفِ وَجَهَرَ بِالْقِرَاءَةِ فِيهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَاهُ أَبُو إِسْحَاقَ الْفَزَارِيُّ عَنْ سُفْيَانَ بْنِ حُسَيْنٍ نَحْوَهُ ‏.‏ وَبِهَذَا الْحَدِيثِ يَقُولُ مَالِكُ بْنُ أَنَسٍ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{563}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated:"The Prophet prayed the eclipse payer, and he recited aloud in it}}
\hadithdefcmd{tirmidhi}{564}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى صَلاَةَ الْخَوْفِ بِإِحْدَى الطَّائِفَتَيْنِ رَكْعَةً وَالطَّائِفَةُ الأُخْرَى مُوَاجِهَةُ الْعَدُوِّ ثُمَّ انْصَرَفُوا فَقَامُوا فِي مَقَامِ أُولَئِكَ وَجَاءَ أُولَئِكَ فَصَلَّى بِهِمْ رَكْعَةً أُخْرَى ثُمَّ سَلَّمَ عَلَيْهِمْ فَقَامَ هَؤُلاَءِ فَقَضَوْا رَكْعَتَهُمْ وَقَامَ هَؤُلاَءِ فَقَضَوْا رَكْعَتَهُمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى مُوسَى بْنُ عُقْبَةَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ مِثْلَ هَذَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَحُذَيْفَةَ وَزَيْدِ بْنِ ثَابِتٍ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَابْنِ مَسْعُودٍ وَسَهْلِ بْنِ أَبِي حَثْمَةَ وَأَبِي عَيَّاشٍ الزُّرَقِيِّ وَاسْمُهُ زَيْدُ بْنُ صَامِتٍ وَأَبِي بَكْرَةَ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ ذَهَبَ مَالِكُ بْنُ أَنَسٍ فِي صَلاَةِ الْخَوْفِ إِلَى حَدِيثِ سَهْلِ بْنِ أَبِي حَثْمَةَ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏ وَقَالَ أَحْمَدُ قَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم صَلاَةُ الْخَوْفِ عَلَى أَوْجُهٍ وَمَا أَعْلَمُ فِي هَذَا الْبَابِ إِلاَّ حَدِيثًا صَحِيحًا وَأَخْتَارُ حَدِيثَ سَهْلِ بْنِ أَبِي حَثْمَةَ ‏.‏ وَهَكَذَا قَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ قَالَ ثَبَتَتِ الرِّوَايَاتُ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي صَلاَةِ الْخَوْفِ ‏.‏ وَرَأَى أَنَّ كُلَّ مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي صَلاَةِ الْخَوْفِ فَهُوَ جَائِزٌ وَهَذَا عَلَى قَدْرِ الْخَوْفِ ‏.‏ قَالَ إِسْحَاقُ وَلَسْنَا نَخْتَارُ حَدِيثَ سَهْلِ بْنِ أَبِي حَثْمَةَ عَلَى غَيْرِهِ مِنَ الرِّوَايَاتِ ‏.‏\hadithno{564}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Salim narrated from his father:"The Prophet prayed Salat Al-Khawf, praying one Rak'ah with one of the two groups, while the other group was facing the enemy. (When the first group finished they first Rak'ah with him), they went and took position (of the second group, facing the enemy). Then the second group came and he led them in another Rak'ah, then he said the Taslim to them, while the group proceeded to complete their (second) Rak'ah. Thereafter, the first group stood up to finish their (second) Rak'ah}}
\hadithdefcmd{tirmidhi}{565}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الأَنْصَارِيُّ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ صَالِحِ بْنِ خَوَّاتِ بْنِ جُبَيْرٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، أَنَّهُ قَالَ فِي صَلاَةِ الْخَوْفِ قَالَ يَقُومُ الإِمَامُ مُسْتَقْبِلَ الْقِبْلَةِ وَتَقُومُ طَائِفَةٌ مِنْهُمْ مَعَهُ وَطَائِفَةٌ مِنْ قِبَلِ الْعَدُوِّ وَوُجُوهُمْ إِلَى الْعَدُوِّ فَيَرْكَعُ بِهِمْ رَكْعَةً وَيَرْكَعُونَ لأَنْفُسِهِمْ رَكْعَةً وَيَسْجُدُونَ لأَنْفُسِهِمْ سَجْدَتَيْنِ فِي مَكَانِهِمْ ثُمَّ يَذْهَبُونَ إِلَى مَقَامِ أُولَئِكَ وَيَجِيءُ أُولَئِكَ فَيَرْكَعُ بِهِمْ رَكْعَةً وَيَسْجُدُ بِهِمْ سَجْدَتَيْنِ فَهِيَ لَهُ ثِنْتَانِ وَلَهُمْ وَاحِدَةٌ ثُمَّ يَرْكَعُونَ رَكْعَةً وَيَسْجُدُونَ سَجْدَتَيْنِ ‏.‏\hadithno{565}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sahl bin Abi Hathmah said about Salat Al-Khawf:"The Imam stands facing the Qiblah while a group of them stand with him, and a group is before the enemy, facing the enemy. He leads them in a Rak'ah, and they perform a bowing by themselves, and they perform two prostrations in their places. Then they go to take the position of the others and the others come (for prayers). He (the Imam) bows for one Rak'ah with them and performs two prostrations with them. That is two for him and one for them, then they perform one bowing and two prostrations}}
\hadithdefcmd{tirmidhi}{566}{قَالَ أَبُو عِيسَى قَالَ مُحَمَّدُ بْنُ بَشَّارٍ سَأَلْتُ يَحْيَى بْنَ سَعِيدٍ عَنْ هَذَا الْحَدِيثِ، فَحَدَّثَنِي عَنْ شُعْبَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ صَالِحِ بْنِ خَوَّاتٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ ‏.‏ وَقَالَ لِي يَحْيَى اكْتُبْهُ إِلَى جَنْبِهِ وَلَسْتُ أَحْفَظُ الْحَدِيثَ وَلَكِنَّهُ مِثْلُ حَدِيثِ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ لَمْ يَرْفَعْهُ يَحْيَى بْنُ سَعِيدٍ الأَنْصَارِيُّ عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ وَهَكَذَا رَوَى أَصْحَابُ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ مَوْقُوفًا وَرَفَعَهُ شُعْبَةُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ بْنِ مُحَمَّدٍ ‏.‏\hadithno{566}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{(Abu Eisa said:) Muhammad bin Bash-har said: "I asked Yahya bin Sa'eed (narrators in no. 565) about this Hadith. So he narrated it to me from Shu'bah, from Abdur-Rahman bin Al-Qasim, from his father, from Salih bin Khawwat, from Sahl bin Abi Hathmah, from the Prophet - the same as the Hadith of Yahya bin Sa'eed Al-Ansari. And he (Yahya) said to me: "Write it next to it. He did not memorize the Hadith better though, rather it is the same Hadith as that of Yahya bin Sa'eed Al-Ansari'" (a Hadith similar to no. 565, with a different chain of narrators)}}
\hadithdefcmd{tirmidhi}{567}{وَرَوَى مَالِكُ بْنُ أَنَسٍ، عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ صَالِحِ بْنِ خَوَّاتٍ، عَمَّنْ صَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَبِهِ يَقُولُ مَالِكٌ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَرُوِيَ عَنْ غَيْرِ وَاحِدٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى بِإِحْدَى الطَّائِفَتَيْنِ رَكْعَةً رَكْعَةً فَكَانَتْ لِلنَّبِيِّ صلى الله عليه وسلم رَكْعَتَانِ وَلَهُمْ رَكْعَةٌ رَكْعَةٌ ‏.‏ قَالَ أَبُو عِيسَى أَبُو عَيَّاشٍ الزُّرَقِيُّ اسْمُهُ زَيْدُ بْنُ صَامِتٍ ‏.‏\hadithno{567}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was reported by Malik from Yazid bin Ruman, :from Salih bin Khawwat, from someone who prayed Salat Al-Khawf with the Prophet, and he mentioned a similar narration}}
\hadithdefcmd{tirmidhi}{568}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ عُمَرَ الدِّمَشْقِيِّ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ سَجَدْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِحْدَى عَشْرَةَ سَجْدَةً مِنْهَا الَّتِي فِي النَّجْمِ ‏.‏\hadithno{568}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Ad-Darda narrated:"I performed eleven prostrations (of recitation) with the Messenger of Allah, among them was that which is in Surat An-Najm}}
\hadithdefcmd{tirmidhi}{569}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ صَالِحٍ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ عُمَرَ، وَهُوَ ابْنُ حَيَّانَ الدِّمَشْقِيُّ قَالَ سَمِعْتُ مُخْبِرًا، يُخْبِرُ عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِلَفْظِهِ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنْ حَدِيثِ سُفْيَانَ بْنِ وَكِيعٍ عَنْ عَبْدِ اللَّهِ بْنِ وَهْبٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَابْنِ مَسْعُودٍ وَزَيْدِ بْنِ ثَابِتٍ وَعَمْرِو بْنِ الْعَاصِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي الدَّرْدَاءِ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ سَعِيدِ بْنِ أَبِي هِلاَلٍ عَنْ عُمَرَ الدِّمَشْقِيِّ ‏.‏\hadithno{569}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{(Another chain in which) Abu Ad-Darda narrated:"I performed eleven prostrations with the Messenger of Allah, among them was that which is in Surat An-Najm}}
\hadithdefcmd{tirmidhi}{570}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، قَالَ كُنَّا عِنْدَ ابْنِ عُمَرَ فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ايذَنُوا لِلنِّسَاءِ بِاللَّيْلِ إِلَى الْمَسَاجِدِ ‏"‏ ‏.‏ فَقَالَ ابْنُهُ وَاللَّهِ لاَ نَأْذَنُ لَهُنَّ يَتَّخِذْنَهُ دَغَلاً ‏.‏ فَقَالَ فَعَلَ اللَّهُ بِكَ وَفَعَلَ أَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَتَقُولُ لاَ نَأْذَنُ لَهُنَّ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَزَيْنَبَ امْرَأَةِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَزَيْدِ بْنِ خَالِدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{570}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Mujahid narrated:"We were with Ibn Umar, and he said: 'The Messenger of Allah said: "Permit the women to go at night to the Masajid." His son said: 'By Allah! We would not permit them lest they become insidious from that.' So he (Abdullah) retorted: 'May Allah do and such with you.' I say: "The Messenger of Allah said," and you say: "We do not permit them?}}
\hadithdefcmd{tirmidhi}{571}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ طَارِقِ بْنِ عَبْدِ اللَّهِ الْمُحَارِبِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كُنْتَ فِي الصَّلاَةِ فَلاَ تَبْزُقْ عَنْ يَمِينِكَ وَلَكِنْ خَلْفَكَ أَوْ تِلْقَاءَ شِمَالِكَ أَوْ تَحْتَ قَدَمِكَ الْيُسْرَى ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَابْنِ عُمَرَ وَأَنَسٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ طَارِقٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ قَالَ وَسَمِعْتُ الْجَارُودَ يَقُولُ سَمِعْتُ وَكِيعًا يَقُولُ لَمْ يَكْذِبْ رِبْعِيُّ بْنُ حِرَاشٍ فِي الإِسْلاَمِ كَذْبَةً ‏.‏ قَالَ وَقَالَ عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ أَثْبَتُ أَهْلِ الْكُوفَةِ مَنْصُورُ بْنُ الْمُعْتَمِرِ ‏.‏\hadithno{571}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Tariq bin Abdullah Al-Muharibi narrated that :the Messenger of Allah said: "When you are in Salat then do not spit on your right, but behind you or toward your left, or under your left foot}}
\hadithdefcmd{tirmidhi}{572}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبُزَاقُ فِي الْمَسْجِدِ خَطِيئَةٌ وَكَفَّارَتُهَا دَفْنُهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{572}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated that :the Messenger of Allah said: "To spit in the Masjid is a sin, and burying it is its atonement}}
\hadithdefcmd{tirmidhi}{573}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ عَطَاءِ بْنِ مِينَاءَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَجَدْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ‏(‏اقْرَأْ بِاسْمِ رَبِّكَ الَّذِي خَلَقَ ‏)‏ وَ ‏(‏إِذََا السَّمَاءُ انْشَقَّتْ ‏)‏\hadithno{573}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated:"We prostrated with the Messenger of Allah in: 'Read! In the Name of your Lord' and 'When the heaven is split asunder}}
\hadithdefcmd{tirmidhi}{574}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدٍ، هُوَ ابْنُ عَمْرِو بْنِ حَزْمٍ عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ يَرَوْنَ السُّجُودَ فِي‏(‏إِذََا السَّمَاءُ انْشَقَّتْ ‏)‏ وَ ‏(‏اقْرَأْ بِاسْمِ رَبِّكَ ‏)‏ ‏.‏ وَفِي هَذَا الْحَدِيثِ أَرْبَعَةٌ مِنَ التَّابِعِينَ بَعْضُهُمْ عَنْ بَعْضٍ ‏.‏\hadithno{574}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{(Another chain in which) Abu Hurairah narrated :from the Prophet similarly}}
\hadithdefcmd{tirmidhi}{575}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْبَزَّازُ الْبَغْدَادِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا أَبِي، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِيهَا - يَعْنِي النَّجْمَ - وَالْمُسْلِمُونَ وَالْمُشْرِكُونَ وَالْجِنُّ وَالإِنْسُ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ يَرَوْنَ السُّجُودَ فِي سُورَةِ النَّجْمِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ لَيْسَ فِي الْمُفَصَّلِ سَجْدَةٌ ‏.‏ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ وَبِهِ يَقُولُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَبِي هُرَيْرَةَ ‏.‏\hadithno{575}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"The Messenger of Allah prostrated for it - meaning (in Surat) An-Najm - and so did the Muslims, the idolaters, the Jinns, and the people}}
\hadithdefcmd{tirmidhi}{576}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ قَرَأْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم النَّجْمَ فَلَمْ يَسْجُدْ فِيهَا ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ زَيْدِ بْنِ ثَابِتٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَتَأَوَّلَ بَعْضُ أَهْلِ الْعِلْمِ هَذَا الْحَدِيثَ فَقَالَ إِنَّمَا تَرَكَ النَّبِيُّ صلى الله عليه وسلم السُّجُودَ لأَنَّ زَيْدَ بْنَ ثَابِتٍ حِينَ قَرَأَ فَلَمْ يَسْجُدْ لَمْ يَسْجُدِ النَّبِيُّ صلى الله عليه وسلم ‏.‏ وَقَالُوا السَّجْدَةُ وَاجِبَةٌ عَلَى مَنْ سَمِعَهَا فَلَمْ يُرَخِّصُوا فِي تَرْكِهَا ‏.‏ وَقَالُوا إِنْ سَمِعَ الرَّجُلُ وَهُوَ عَلَى غَيْرِ وُضُوءٍ فَإِذَا تَوَضَّأَ سَجَدَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ وَبِهِ يَقُولُ إِسْحَاقُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِنَّمَا السَّجْدَةُ عَلَى مَنْ أَرَادَ أَنْ يَسْجُدَ فِيهَا وَالْتَمَسَ فَضْلَهَا وَرَخَّصُوا فِي تَرْكِهَا إِنْ أَرَادَ ذَلِكَ ‏.‏ وَاحْتَجُّوا بِالْحَدِيثِ الْمَرْفُوعِ حَدِيثِ زَيْدِ بْنِ ثَابِتٍ حَيْثُ قَالَ قَرَأْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم النَّجْمَ فَلَمْ يَسْجُدْ فِيهَا ‏.‏ فَقَالُوا لَوْ كَانَتِ السَّجْدَةُ وَاجِبَةً لَمْ يَتْرُكِ النَّبِيُّ صلى الله عليه وسلم زَيْدًا حَتَّى كَانَ يَسْجُدُ وَيَسْجُدُ النَّبِيُّ صلى الله عليه وسلم ‏.‏ وَاحْتَجُّوا بِحَدِيثِ عُمَرَ أَنَّهُ قَرَأَ سَجْدَةً عَلَى الْمِنْبَرِ فَنَزَلَ فَسَجَدَ ثُمَّ قَرَأَهَا فِي الْجُمُعَةِ الثَّانِيَةِ فَتَهَيَّأَ النَّاسُ لِلسُّجُودِ فَقَالَ إِنَّهَا لَمْ تُكْتَبْ عَلَيْنَا إِلاَّ أَنْ نَشَاءَ ‏.‏ فَلَمْ يَسْجُدْ وَلَمْ يَسْجُدُوا ‏.‏ فَذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ ‏.‏\hadithno{576}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Zaid bin Thabit narrated:"I recited Surat An-Najm to the Messenger of Allah, and he did not prostrate for it}}
\hadithdefcmd{tirmidhi}{577}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْجُدُ فِي ص ‏.‏ قَالَ ابْنُ عَبَّاسٍ وَلَيْسَتْ مِنْ عَزَائِمِ السُّجُودِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي ذَلِكَ فَرَأَى بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنْ يَسْجُدَ فِيهَا ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُهُمْ إِنَّهَا تَوْبَةُ نَبِيٍّ وَلَمْ يَرَوُا السُّجُودَ فِيهَا ‏.‏\hadithno{577}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Abbas narrated:"I saw the Messenger of Allah prostrating for (Surat) Sad." Ibn Abbas said: "It is not one of the resolute prostrations}}
\hadithdefcmd{tirmidhi}{578}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ مِشْرَحِ بْنِ هَاعَانَ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ فُضِّلَتْ سُورَةُ الْحَجِّ بِأَنَّ فِيهَا سَجْدَتَيْنِ قَالَ ‏ "‏ نَعَمْ وَمَنْ لَمْ يَسْجُدْهُمَا فَلاَ يَقْرَأْهُمَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِذَاكَ الْقَوِيِّ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي هَذَا فَرُوِيَ عَنْ عُمَرَ بْنِ الْخَطَّابِ وَابْنِ عُمَرَ أَنَّهُمَا قَالاَ فُضِّلَتْ سُورَةُ الْحَجِّ بِأَنَّ فِيهَا سَجْدَتَيْنِ ‏.‏ وَبِهِ يَقُولُ ابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَرَأَى بَعْضُهُمْ فِيهَا سَجْدَةً وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكٍ وَأَهْلِ الْكُوفَةِ ‏.‏\hadithno{578}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Uqbah bin Amir narrated:"I said: 'O Messenger of Allah! Surah Al-Hajj has been esteemed by two prostrations?' He said: 'Yes, and whoever does not prostrate for them, he should not recite them}}
\hadithdefcmd{tirmidhi}{579}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ بْنِ خُنَيْسٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، قَالَ قَالَ لِي ابْنُ جُرَيْجٍ يَا حَسَنُ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي يَزِيدَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي رَأَيْتُنِي اللَّيْلَةَ وَأَنَا نَائِمٌ كَأَنِّي أُصَلِّي خَلْفَ شَجَرَةٍ فَسَجَدْتُ فَسَجَدَتِ الشَّجَرَةُ لِسُجُودِي فَسَمِعْتُهَا وَهِيَ تَقُولُ اللَّهُمَّ اكْتُبْ لِي بِهَا عِنْدَكَ أَجْرًا وَضَعْ عَنِّي بِهَا وِزْرًا وَاجْعَلْهَا لِي عِنْدَكَ ذُخْرًا وَتَقَبَّلْهَا مِنِّي كَمَا تَقَبَّلْتَهَا مِنْ عَبْدِكَ دَاوُدَ ‏.‏ قَالَ الْحَسَنُ قَالَ لِي ابْنُ جُرَيْجٍ قَالَ لِي جَدُّكَ قَالَ ابْنُ عَبَّاسٍ فَقَرَأَ النَّبِيُّ صلى الله عليه وسلم سَجْدَةً ثُمَّ سَجَدَ ‏.‏ قَالَ فَقَالَ ابْنُ عَبَّاسٍ فَسَمِعْتُهُ وَهُوَ يَقُولُ مِثْلَ مَا أَخْبَرَهُ الرَّجُلُ عَنْ قَوْلِ الشَّجَرَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ عَبَّاسٍ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{579}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Al-Hasan bin Muhammad bin Ubaidullah bin Abi Yazid said:Ibn Juraij said to me: O Hasan! Ubaidullah bin Abi Yazid informed me that Ibn Abbas said: "A man came to the Prophet and said: 'O Messenger of Allah! I had a dream at night while I was sleeping in which I was praying behind a tree, when I prostrated the tree prostrated along with me. Then I heard it saying: (Allahummaktuh li biha indaka ajran, wad a anni biha wizran, waj'alha li biha indaka dhukhran, wa taqabbalha minni kama taqabbaltaha min abdiki Dawud.)" (O Allah! Record for me, a reward with You for it, remove a sin for me by it, and store it away for me with You, and accept it from me as You accepted it from Your worshipper Dawud). Al-Hasan said: "Ibn Juraij said to me: 'Your grandfather said to me: 'Ibn Abbas said: 'So the Prophet recited (an Ayah of) prostration then prostrated.'" (He said) "So Ibn Abbas said: 'I listened to him, and he was saying the same as the man informed that the tree had said}}
\hadithdefcmd{tirmidhi}{580}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي الْعَالِيَةِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي سُجُودِ الْقُرْآنِ بِاللَّيْلِ ‏ "‏ سَجَدَ وَجْهِيَ لِلَّذِي خَلَقَهُ وَشَقَّ سَمْعَهُ وَبَصَرَهُ بِحَوْلِهِ وَقُوَّتِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{580}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aisha narrated:"When the Messenger of Allah would prostrate (for recitation of) the Qur'an, he would say: (Sajada wajhiya lilladhi khalaqahu wa shaqqa sam'ahu wa basarahu bihawlihi wa quwwatihi.) (I have prostrated my face to the One Who created it, and made its hearing and vision, though His ability and power)}}
\hadithdefcmd{tirmidhi}{581}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو صَفْوَانَ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ الزُّهْرِيِّ، أَنَّ السَّائِبَ بْنَ يَزِيدَ، وَعُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَخْبَرَاهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَامَ عَنْ حِزْبِهِ أَوْ عَنْ شَيْءٍ مِنْهُ فَقَرَأَهُ مَا بَيْنَ صَلاَةِ الْفَجْرِ وَصَلاَةِ الظُّهْرِ كُتِبَ لَهُ كَأَنَّمَا قَرَأَهُ مِنَ اللَّيْلِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَأَبُو صَفْوَانَ اسْمُهُ عَبْدُ اللَّهِ بْنُ سَعِيدٍ الْمَكِّيُّ وَرَوَى عَنْهُ الْحُمَيْدِيُّ وَكِبَارُ النَّاسِ ‏.‏\hadithno{581}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Umar bin Al-Khattab narrated that :the Messenger of Allah said: "Whoever slept, (missing) his section or some of it, then he recited it between the Fajr prayer and the Zuhr prayer, it is written for him as if he had recited it in the night}}
\hadithdefcmd{tirmidhi}{582}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، وَهُوَ أَبُو الْحَارِثِ الْبَصْرِيُّ ثِقَةٌ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ مُحَمَّدٌ صلى الله عليه وسلم ‏"‏ أَمَا يَخْشَى الَّذِي يَرْفَعُ رَأْسَهُ قَبْلَ الإِمَامِ أَنْ يُحَوِّلَ اللَّهُ رَأْسَهُ رَأْسَ حِمَارٍ ‏"‏ ‏.‏ قَالَ قُتَيْبَةُ قَالَ حَمَّادٌ قَالَ لِي مُحَمَّدُ بْنُ زِيَادٍ وَإِنَّمَا قَالَ ‏"‏ أَمَا يَخْشَى ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمُحَمَّدُ بْنُ زِيَادٍ هُوَ بَصْرِيٌّ ثِقَةٌ وَيُكْنَى أَبَا الْحَارِثِ ‏.‏\hadithno{582}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated:"Muhammad said: 'Does not the one who raises his head before the Imam fear that Allah will transform his head into a donkey's head?}}
\hadithdefcmd{tirmidhi}{583}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ مُعَاذَ بْنَ جَبَلٍ، كَانَ يُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْمَغْرِبَ ثُمَّ يَرْجِعُ إِلَى قَوْمِهِ فَيَؤُمُّهُمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَصْحَابِنَا الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ قَالُوا إِذَا أَمَّ الرَّجُلُ الْقَوْمَ فِي الْمَكْتُوبَةِ وَقَدْ كَانَ صَلاَّهَا قَبْلَ ذَلِكَ أَنَّ صَلاَةَ مَنِ ائْتَمَّ بِهِ جَائِزَةٌ ‏.‏ وَاحْتَجُّوا بِحَدِيثِ جَابِرٍ فِي قِصَّةِ مُعَاذٍ وَهُوَ حَدِيثٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ جَابِرٍ ‏.‏ وَرُوِيَ عَنْ أَبِي الدَّرْدَاءِ أَنَّهُ سُئِلَ عَنْ رَجُلٍ دَخَلَ الْمَسْجِدَ وَالْقَوْمُ فِي صَلاَةِ الْعَصْرِ وَهُوَ يَحْسَبُ أَنَّهَا صَلاَةُ الظُّهْرِ فَائْتَمَّ بِهِمْ قَالَ صَلاَتُهُ جَائِزَةٌ ‏.‏ وَقَدْ قَالَ قَوْمٌ مِنْ أَهْلِ الْكُوفَةِ إِذَا ائْتَمَّ قَوْمٌ بِإِمَامٍ وَهُوَ يُصَلِّي الْعَصْرَ وَهُمْ يَحْسَبُونَ أَنَّهَا الظُّهْرُ فَصَلَّى بِهِمْ وَاقْتَدَوْا بِهِ فَإِنَّ صَلاَةَ الْمُقْتَدِي فَاسِدَةٌ إِذِ اخْتَلَفَ نِيَّةُ الإِمَامِ وَنِيَّةُ الْمَأْمُومِ ‏.‏\hadithno{583}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir bin Abdullah narrated:'Mu'adh bin Jabal would pray Al-Maghrib with the Messenger of Allah, then he would return to his people to lead them (in prayer)}}
\hadithdefcmd{tirmidhi}{584}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي غَالِبٌ الْقَطَّانُ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا إِذَا صَلَّيْنَا خَلْفَ النَّبِيِّ صلى الله عليه وسلم بِالظَّهَائِرِ سَجَدْنَا عَلَى ثِيَابِنَا اتِّقَاءَ الْحَرِّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ وَابْنِ عَبَّاسٍ ‏.‏ وَقَدْ رَوَى وَكِيعٌ هَذَا الْحَدِيثَ عَنْ خَالِدِ بْنِ عَبْدِ الرَّحْمَنِ ‏.‏\hadithno{584}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated:"When we prayed behind the Prophet in the midday heat, we would prostrate on our garments as a protection against the heat}}
\hadithdefcmd{tirmidhi}{585}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا صَلَّى الْفَجْرَ قَعَدَ فِي مُصَلاَّهُ حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{585}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir bin Samurah narrated:"When the Prophet prayed Fajr he would remain seated where he had prayed until the sun had risen}}
\hadithdefcmd{tirmidhi}{586}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو ظِلاَلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ صَلَّى الْغَدَاةَ فِي جَمَاعَةٍ ثُمَّ قَعَدَ يَذْكُرُ اللَّهَ حَتَّى تَطْلُعَ الشَّمْسُ ثُمَّ صَلَّى رَكْعَتَيْنِ كَانَتْ لَهُ كَأَجْرِ حَجَّةٍ وَعُمْرَةٍ ‏"‏ ‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَامَّةٍ تَامَّةٍ تَامَّةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ عَنْ أَبِي ظِلاَلٍ فَقَالَ هُوَ مُقَارِبُ الْحَدِيثِ ‏.‏ قَالَ مُحَمَّدٌ وَاسْمُهُ هِلاَلٌ ‏.‏\hadithno{586}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that :the Messenger of Allah said: "Whoever prays Fajr in congregation, then sits remembering Allah until the sun has risen, then he prays two Rak'ah, then for him is the reward like that of a Hajj and Umrah." He said: "The Messenger of Allah said: 'Complete, complete, complete}}
\hadithdefcmd{tirmidhi}{587}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَلْحَظُ فِي الصَّلاَةِ يَمِينًا وَشِمَالاً وَلاَ يَلْوِي عُنُقَهُ خَلْفَ ظَهْرِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ خَالَفَ وَكِيعٌ الْفَضْلَ بْنَ مُوسَى فِي رِوَايَتِهِ ‏.‏\hadithno{587}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Abbas narrated:"The Messenger of Allah would glance toward the right and the left during Salat but he would not turn his neck to look behind him}}
\hadithdefcmd{tirmidhi}{588}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ بَعْضِ، أَصْحَابِ عِكْرِمَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَلْحَظُ فِي الصَّلاَةِ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَعَائِشَةَ ‏.‏\hadithno{588}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{Sa'eed bin Abi Hind narrated from some of the companions of Ikrimah:"The Prophet would glance during Salat" and he mentioned a similar narration}}
\hadithdefcmd{tirmidhi}{589}{حَدَّثَنَا أَبُو حَاتِمٍ، مُسْلِمُ بْنُ حَاتِمٍ الْبَصْرِيُّ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ قَالَ أَنَسُ بْنُ مَالِكٍ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا بُنَىَّ إِيَّاكَ وَالاِلْتِفَاتَ فِي الصَّلاَةِ فَإِنَّ الاِلْتِفَاتَ فِي الصَّلاَةِ هَلَكَةٌ فَإِنْ كَانَ لاَ بُدَّ فَفِي التَّطَوُّعِ لاَ فِي الْفَرِيضَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{589}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated:"The Messenger of Allah said to me: 'O my son! Beware of looking around during the Salat, for indeed looking around during Salat is destruction. If you must do so, then in the voluntary (prayers), not in the obligatory (prayers).'" (Da'if)}}
\hadithdefcmd{tirmidhi}{590}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ الاِلْتِفَاتِ فِي الصَّلاَةِ قَالَ ‏ "‏ هُوَ اخْتِلاَسٌ يَخْتَلِسُهُ الشَّيْطَانُ مِنْ صَلاَةِ الرَّجُلِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{590}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Aishah narrated:"I asked the Messenger of Allah about looking around during the Salat. He said: 'It is a portion which the Shaitan snatches during a man's prayer}}
\hadithdefcmd{tirmidhi}{591}{حَدَّثَنَا هِشَامُ بْنُ يُونُسَ الْكُوفِيُّ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنِ الْحَجَّاجِ بْنِ أَرْطَاةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ هُبَيْرَةَ بْنِ يَرِيمَ، عَنْ عَلِيٍّ، وَعَنْ عَمْرِو بْنِ مُرَّةَ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالاَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا أَتَى أَحَدُكُمُ الصَّلاَةَ وَالإِمَامُ عَلَى حَالٍ فَلْيَصْنَعْ كَمَا يَصْنَعُ الإِمَامُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْلَمُ أَحَدًا أَسْنَدَهُ إِلاَّ مَا رُوِيَ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ قَالُوا إِذَا جَاءَ الرَّجُلُ وَالإِمَامُ سَاجِدٌ فَلْيَسْجُدْ وَلاَ تُجْزِئُهُ تِلْكَ الرَّكْعَةُ إِذَا فَاتَهُ الرُّكُوعُ مَعَ الإِمَامِ وَاخْتَارَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ أَنْ يَسْجُدَ مَعَ الإِمَامِ وَذَكَرَ عَنْ بَعْضِهِمْ فَقَالَ لَعَلَّهُ لاَ يَرْفَعُ رَأْسَهُ فِي تِلْكَ السَّجْدَةِ حَتَّى يُغْفَرَ لَهُ ‏.‏\hadithno{591}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Mu'adh bin Jabal narrated that :the Messenger of Allah said: "When one of you comes to the Salat and (finds) the Imam is in a position, then do as the Imam is doing}}
\hadithdefcmd{tirmidhi}{592}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ تَقُومُوا حَتَّى تَرَوْنِي خَرَجْتُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَحَدِيثُ أَنَسٍ غَيْرُ مَحْفُوظٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي قَتَادَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنْ يَنْتَظِرَ النَّاسُ الإِمَامَ وَهُمْ قِيَامٌ ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا كَانَ الإِمَامُ فِي الْمَسْجِدِ فَأُقِيمَتِ الصَّلاَةُ فَإِنَّمَا يَقُومُونَ إِذَا قَالَ الْمُؤَذِّنُ قَدْ قَامَتِ الصَّلاَةُ قَدْ قَامَتِ الصَّلاَةُ ‏.‏ وَهُوَ قَوْلُ ابْنِ الْمُبَارَكِ ‏.‏\hadithno{592}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Abi Qatadah narrated from his father that :the Messenger of Allah said: "When the Iqamah is called for the prayer, then do not stand until you see that I have come out}}
\hadithdefcmd{tirmidhi}{593}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنْتُ أُصَلِّي وَالنَّبِيُّ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ مَعَهُ فَلَمَّا جَلَسْتُ بَدَأْتُ بِالثَّنَاءِ عَلَى اللَّهِ ثُمَّ الصَّلاَةِ عَلَى النَّبِيِّ صلى الله عليه وسلم ثُمَّ دَعَوْتُ لِنَفْسِي فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ سَلْ تُعْطَهْ سَلْ تُعْطَهْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ فَضَالَةَ بْنِ عُبَيْدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا الْحَدِيثُ رَوَاهُ أَحْمَدُ بْنُ حَنْبَلٍ عَنْ يَحْيَى بْنِ آدَمَ مُخْتَصَرًا ‏.‏\hadithno{593}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah said:"I was prayed and the Prophet, Abu Bakr, and Umar were there, so when I sat, I started off with praising Allah, then sending Salat upon the Prophet, then supplicating for myself. So the Prophet said: 'Ask, your request will be granted, ask, your request will be ranted}}
\hadithdefcmd{tirmidhi}{594}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْمُؤَدِّبُ الْبَغْدَادِيُّ الْبَصْرِيُّ، حَدَّثَنَا عَامِرُ بْنُ صَالِحٍ الزُّبَيْرِيُّ، هُوَ مِنْ وَلَدِ الزُّبَيْرِ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِبِنَاءِ الْمَسَاجِدِ فِي الدُّورِ وَأَنْ تُنَظَّفَ وَتُطَيَّبَ ‏.‏\hadithno{594}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated:"The Prophet ordered the construction of Masajid in all Dur and that they be kept clean and scented}}
\hadithdefcmd{tirmidhi}{595}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، وَوَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنَ الْحَدِيثِ الأَوَّلِ ‏.‏\hadithno{595}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{(Another chain) from Hisham bin Urwah, from his father:"That the Prophet ordered." And he mentioned similarly}}
\hadithdefcmd{tirmidhi}{596}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ سُفْيَانُ قَوْلُهُ ‏ "‏ بِبِنَاءِ الْمَسَاجِدِ فِي الدُّورِ ‏"‏ ‏.‏ يَعْنِي الْقَبَائِلَ ‏.‏\hadithno{596}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{(Another chain) from Hisham from Urwah, from his father:"That the Prophet ordered." And he mentioned similarly}}
\hadithdefcmd{tirmidhi}{597}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ عَلِيٍّ الأَزْدِيِّ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ صَلاَةُ اللَّيْلِ وَالنَّهَارِ مَثْنَى مَثْنَى ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى اخْتَلَفَ أَصْحَابُ شُعْبَةَ فِي حَدِيثِ ابْنِ عُمَرَ فَرَفَعَهُ بَعْضُهُمْ وَأَوْقَفَهُ بَعْضُهُمْ ‏.‏ وَرُوِيَ عَنْ عَبْدِ اللَّهِ الْعُمَرِيِّ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ هَذَا ‏.‏ وَالصَّحِيحُ مَا رُوِيَ عَنِ ابْنِ عُمَرَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى ‏"‏ ‏.‏ وَرَوَى الثِّقَاتُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرُوا فِيهِ صَلاَةَ النَّهَارِ ‏.‏ وَقَدْ رُوِيَ عَنْ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ أَنَّهُ كَانَ يُصَلِّي بِاللَّيْلِ مَثْنَى مَثْنَى وَبِالنَّهَارِ أَرْبَعًا ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي ذَلِكَ فَرَأَى بَعْضُهُمْ أَنَّ صَلاَةَ اللَّيْلِ وَالنَّهَارِ مَثْنَى مَثْنَى ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ ‏.‏ وَقَالَ بَعْضُهُمْ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى وَرَأَوْا صَلاَةَ التَّطَوُّعِ بِالنَّهَارِ أَرْبَعًا مِثْلَ الأَرْبَعِ قَبْلَ الظُّهْرِ وَغَيْرِهَا مِنْ صَلاَةِ التَّطَوُّعِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَإِسْحَاقَ ‏.‏\hadithno{597}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Umar narrated that :the Prophet said: "The Salat during the night and the day is two and two}}
\hadithdefcmd{tirmidhi}{598}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، قَالَ سَأَلْنَا عَلِيًّا عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ النَّهَارِ فَقَالَ إِنَّكُمْ لاَ تُطِيقُونَ ذَاكَ ‏.‏ فَقُلْنَا مَنْ أَطَاقَ ذَاكَ مِنَّا ‏.‏ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا كَانَتِ الشَّمْسُ مِنْ هَا هُنَا كَهَيْئَتِهَا مِنْ هَا هُنَا عِنْدَ الْعَصْرِ صَلَّى رَكْعَتَيْنِ وَإِذَا كَانَتِ الشَّمْسُ مِنْ هَا هُنَا كَهَيْئَتِهَا مِنْ هَا هُنَا عِنْدَ الظُّهْرِ صَلَّى أَرْبَعًا وَصَلَّى أَرْبَعًا قَبْلَ الظُّهْرِ وَبَعْدَهَا رَكْعَتَيْنِ وَقَبْلَ الْعَصْرِ أَرْبَعًا يَفْصِلُ بَيْنَ كُلِّ رَكْعَتَيْنِ بِالتَّسْلِيمِ عَلَى الْمَلاَئِكَةِ الْمُقَرَّبِينَ وَالنَّبِيِّينَ وَالْمُرْسَلِينَ وَمَنْ تَبِعَهُمْ مِنَ الْمُؤْمِنِينَ وَالْمُسْلِمِينَ ‏.‏\hadithno{598}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Asim bin Damrah said:"We asked Ali about the prayer of the Messenger of Allah during the day. He said: 'You will not be able to do that.' We said: 'Whoever among is able (he will)?' So he said: 'When the sun appeared over there (east) like it appears here (west) at Asr, the Messenger of Allah would pray two Rak'ah, and when the sun appeared over there (east) like it appears here (west) at Zuhr, he would pray four Rak'ah. And he would pray four before Zuhr and two after it, and four before Asr separating between every two Rak'ah with At-Taslim upon the angels that are close (to Allah) and those who follow them among the believers, and the Muslims}}
\hadithdefcmd{tirmidhi}{599}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ أَحْسَنُ شَيْءٍ رُوِيَ فِي تَطَوُّعِ النَّبِيِّ صلى الله عليه وسلم فِي النَّهَارِ هَذَا ‏.‏ وَرُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ أَنَّهُ كَانَ يُضَعِّفُ هَذَا الْحَدِيثَ ‏.‏ وَإِنَّمَا ضَعَّفَهُ عِنْدَنَا وَاللَّهُ أَعْلَمُ لأَنَّهُ لاَ يُرْوَى مِثْلُ هَذَا عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ مِنْ هَذَا الْوَجْهِ عَنْ عَاصِمِ بْنِ ضَمْرَةَ عَنْ عَلِيٍّ ‏.‏ وَعَاصِمُ بْنُ ضَمْرَةَ هُوَ ثِقَةٌ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ ‏.‏ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ قَالَ سُفْيَانُ كُنَّا نَعْرِفُ فَضْلَ حَدِيثِ عَاصِمِ بْنِ ضَمْرَةَ عَلَى حَدِيثِ الْحَارِثِ ‏.‏\hadithno{599}\hadithgrade{Zubair Ali Zai: Isnaad Hasan}\hadithtrans{(Another chain) from Ali :from the Prophet similarly (no)}}
\hadithdefcmd{tirmidhi}{600}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ أَشْعَثَ، وَهُوَ ابْنُ عَبْدِ الْمَلِكِ عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يُصَلِّي فِي لُحُفِ نِسَائِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم رُخْصَةٌ فِي ذَلِكَ ‏.‏\hadithno{600}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah narrated:"The Messenger of Allah would not pray in women's covers}}
\hadithdefcmd{tirmidhi}{601}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ بُرْدِ بْنِ سِنَانٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ جِئْتُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي الْبَيْتِ وَالْبَابُ عَلَيْهِ مُغْلَقٌ فَمَشَى حَتَّى فَتَحَ لِي ثُمَّ رَجَعَ إِلَى مَكَانِهِ ‏.‏ وَوَصَفَتِ الْبَابَ فِي الْقِبْلَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{601}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Urwah narrated that Aishah said:"I came while the Messenger of Allah was praying in the house and the door was closed. So he walked until he opened the door for me, then he returned to his place." And she described the door to be in the direction of the Qiblah}}
\hadithdefcmd{tirmidhi}{602}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، قَالَ سَأَلَ رَجُلٌ عَبْدَ اللَّهِ عَنْ هَذَا الْحَرْفِ ‏(‏غَيرِ آسِنٍ‏)‏ أَوْ يَاسِنٍ قَالَ كُلَّ الْقُرْآنِ قَرَأْتَ غَيْرَ هَذَا الْحَرْفِ قَالَ نَعَمْ ‏.‏ قَالَ إِنَّ قَوْمًا يَقْرَءُونَهُ يَنْثُرُونَهُ نَثْرَ الدَّقَلِ لاَ يُجَاوِزُ تَرَاقِيَهُمْ إِنِّي لأَعْرِفُ السُّوَرَ النَّظَائِرَ الَّتِي كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرِنُ بَيْنَهُنَّ ‏.‏ قَالَ فَأَمَرْنَا عَلْقَمَةَ فَسَأَلَهُ فَقَالَ عِشْرُونَ سُورَةً مِنَ الْمُفَصَّلِ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرِنُ بَيْنَ كُلِّ سُورَتَيْنِ فِي رَكْعَةٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{602}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Wa'il said:"A man asked Abdullah bin Mas'ud about this phrase: 'Ghairi asin' or is it Yasin? So he said: 'You can recite all of the Quran besides this [phrase]?' He said: 'Yes.' He said: 'Indeed a people recite it, disbursing it like Ad-Daqqa are dispersed, without it passing their throats. Indeed I am aware of the surahs that are comparable which the Messenger of Allah would recite together.'" He said: "So we told Alqamah to ask him (what they were). He said: "Twenty surahs from the Mufassal from which the Prophet would combine, reciting every two Surah in a Rak'ah}}
\hadithdefcmd{tirmidhi}{603}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، سَمِعَ ذَكْوَانَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَضَّأَ الرَّجُلُ فَأَحْسَنَ الْوُضُوءَ ثُمَّ خَرَجَ إِلَى الصَّلاَةِ لاَ يُخْرِجُهُ أَوْ قَالَ لاَ يَنْهَزُهُ إِلاَّ إِيَّاهَا لَمْ يَخْطُ خُطْوَةً إِلاَّ رَفَعَهُ اللَّهُ بِهَا دَرَجَةً أَوْ حَطَّ عَنْهُ بِهَا خَطِيئَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{603}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "When a man performs Wudu and he performs his Wudu well, then he leaves to the Salat, and he did not leave - or he said: He had no urge - except for it, then there is not one step that he takes except that Allah raises him a degree from it, or removes a sin from him for it}}
\hadithdefcmd{tirmidhi}{604}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ أَبِي الْوَزِيرِ الْبَصْرِيُّ، ثِقَةٌ حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى، عَنْ سَعْدِ بْنِ إِسْحَاقَ بْنِ كَعْبِ بْنِ عُجْرَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم فِي مَسْجِدِ بَنِي عَبْدِ الأَشْهَلِ الْمَغْرِبَ فَقَامَ نَاسٌ يَتَنَفَّلُونَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ عَلَيْكُمْ بِهَذِهِ الصَّلاَةِ فِي الْبُيُوتِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ كَعْبِ بْنِ عُجْرَةَ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالصَّحِيحُ مَا رُوِيَ عَنِ ابْنِ عُمَرَ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي الرَّكْعَتَيْنِ بَعْدَ الْمَغْرِبِ فِي بَيْتِهِ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ عَنْ حُذَيْفَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الْمَغْرِبَ فَمَا زَالَ يُصَلِّي فِي الْمَسْجِدِ حَتَّى صَلَّى الْعِشَاءَ الآخِرَةَ ‏.‏ فَفِي هَذَا الْحَدِيثِ دِلاَلَةٌ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الرَّكْعَتَيْنِ بَعْدَ الْمَغْرِبِ فِي الْمَسْجِدِ ‏.‏\hadithno{604}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sa'd bin Ishaq bin Ka'b bin Ujrah narrated from his father from his grandfather who said:"The Prophet prayed Maghrib in the Masjid of Banu Abdul-Ashbal, and some people stood to offer voluntary prayers, so the Prophet said: 'This Salat is to be performed by you in your homes}}
\hadithdefcmd{tirmidhi}{605}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَغَرِّ بْنِ الصَّبَّاحِ، عَنْ خَلِيفَةَ بْنِ حُصَيْنٍ، عَنْ قَيْسِ بْنِ عَاصِمٍ، أَنَّهُ أَسْلَمَ فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم أَنْ يَغْتَسِلَ بِمَاءٍ وَسِدْرٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ يَسْتَحِبُّونَ لِلرَّجُلِ إِذَا أَسْلَمَ أَنْ يَغْتَسِلَ وَيَغْسِلَ ثِيَابَهُ ‏.‏\hadithno{605}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Qais bin Asim narrated that:he accepted Islam and the Prophet ordered him to perform Ghusl with water and Sidr}}
\hadithdefcmd{tirmidhi}{606}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، حَدَّثَنَا الْحَكَمُ بْنُ بَشِيرِ بْنِ سَلْمَانَ، حَدَّثَنَا خَلاَّدٌ الصَّفَّارُ، عَنِ الْحَكَمِ بْنِ عَبْدِ اللَّهِ النَّصْرِيِّ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي جُحَيْفَةَ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ سَتْرُ مَا بَيْنَ أَعْيُنِ الْجِنِّ وَعَوْرَاتِ بَنِي آدَمَ إِذَا دَخَلَ أَحَدُهُمُ الْخَلاَءَ أَنْ يَقُولَ بِسْمِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَإِسْنَادُهُ لَيْسَ بِذَاكَ الْقَوِيِّ ‏.‏ وَقَدْ رُوِيَ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَشْيَاءُ فِي هَذَا ‏.‏\hadithno{606}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ali bin Abi Talid (may Allah be pleased with him) narrated that :the Messenger of Allah said: "The screen between the eyes of the jinns and nakedness of the children of Adam when one of you enters the area of relieving oneself is saying: 'Bismillah}}
\hadithdefcmd{tirmidhi}{607}{حَدَّثَنَا أَبُو الْوَلِيدِ، أَحْمَدُ بْنُ بَكَّارٍ الدِّمَشْقِيُّ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ قَالَ صَفْوَانُ بْنُ عَمْرٍو أَخْبَرَنِي يَزِيدُ بْنُ خُمَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أُمَّتِي يَوْمَ الْقِيَامَةِ غُرٌّ مِنَ السُّجُودِ مُحَجَّلُونَ مِنَ الْوُضُوءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ بُسْرٍ ‏.‏\hadithno{607}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Busr narrated that :the Prophet said: "On the day of Resurrection, my nation will be radiant from prostrating and shining from Wudu}}
\hadithdefcmd{tirmidhi}{608}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُحِبُّ التَّيَمُّنَ فِي طُهُورِهِ إِذَا تَطَهَّرَ وَفِي تَرَجُّلِهِ إِذَا تَرَجَّلَ وَفِي انْتِعَالِهِ إِذَا انْتَعَلَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو الشَّعْثَاءِ اسْمُهُ سُلَيْمُ بْنُ أَسْوَدَ الْمُحَارِبِيُّ ‏.‏\hadithno{608}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"The Messenger of Allah would love to start with the right side when he purified himself, and when he combed, and when putting his sandals on}}
\hadithdefcmd{tirmidhi}{609}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ شَرِيكٍ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنِ ابْنِ جَبْرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يُجْزِئُ فِي الْوُضُوءِ رِطْلاَنِ مِنْ مَاءٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ شَرِيكٍ عَلَى هَذَا اللَّفْظِ ‏.‏ وَرَوَى شُعْبَةُ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ جَبْرٍ عَنْ أَنَسِ بْنِ مَالِكٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَوَضَّأُ بِالْمَكُّوكِ وَيَغْتَسِلُ بِخَمْسَةِ مَكَاكِيَّ ‏.‏ وَرُوِيَ عَنْ سُفْيَانَ الثَّوْرِيِّ عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى عَنْ عَبْدِ اللَّهِ بْنِ جَبْرٍ عَنْ أَنَسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَوَضَّأُ بِالْمُدِّ وَيَغْتَسِلُ بِالصَّاعِ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ شَرِيكٍ ‏.‏\hadithno{609}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that :the Messenger of Allah said: The acceptable Wudu is with two Ratils of water}}
\hadithdefcmd{tirmidhi}{610}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي حَرْبِ بْنِ أَبِي الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، رضى الله عَنْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي بَوْلِ الْغُلاَمِ الرَّضِيعِ ‏ "‏ يُنْضَحُ بَوْلُ الْغُلاَمِ وَيُغْسَلُ بَوْلُ الْجَارِيَةِ ‏"‏ ‏.‏ قَالَ قَتَادَةُ وَهَذَا مَا لَمْ يَطْعَمَا فَإِذَا طَعِمَا غُسِلاَ جَمِيعًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ رَفَعَ هِشَامٌ الدَّسْتَوَائِيُّ هَذَا الْحَدِيثَ عَنْ قَتَادَةَ وَأَوْقَفَهُ سَعِيدُ بْنُ أَبِي عَرُوبَةَ عَنْ قَتَادَةَ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{610}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ali bin Abi Talib (may Allah be pleased with him) narrated that :the Messenger of Allah said, about urine of a male child that suckles: "The urine of the boy is sprinkled, and the girl's urine is washed." Qatadah (one of the narrators) said: "This is so, as long as they do not eat, when they eat, then both of them are washed}}
\hadithdefcmd{tirmidhi}{611}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا خَالِدُ بْنُ زِيَادٍ، عَنْ مُقَاتِلِ بْنِ حَيَّانَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، قَالَ رَأَيْتُ جَرِيرَ بْنَ عَبْدِ اللَّهِ تَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ قَالَ فَقُلْتُ لَهُ فِي ذَلِكَ فَقَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ فَمَسَحَ عَلَى خُفَّيْهِ ‏.‏ فَقُلْتُ لَهُ أَقَبْلَ الْمَائِدَةِ أَمْ بَعْدَ الْمَائِدَةِ قَالَ مَا أَسْلَمْتُ إِلاَّ بَعْدَ الْمَائِدَةِ ‏.‏\hadithno{611}\hadithgrade{Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Shahr bin Hawshab said:"I saw Jarir bin Abdullah performing Wudu and wiping over his Khuff." He said: "So I asked him: 'What is that?' He said: 'I saw the Prophet performing Wudu and he wiped over his Khuff.' So I said to him: 'Before Al-Ma'idah or after Al-Ma'idah?' He said: 'I did not accept Islam until after Al-Ma'idah}}
\hadithdefcmd{tirmidhi}{612}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، قَالَ حَدَّثَنَا نُعَيْمُ بْنُ مَيْسَرَةَ النَّحْوِيُّ، عَنْ خَالِدِ بْنِ زِيَادٍ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِثْلَ هَذَا إِلاَّ مِنْ حَدِيثِ مُقَاتِلِ بْنِ حَيَّانَ عَنْ شَهْرِ بْنِ حَوْشَبٍ ‏.‏\hadithno{612}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{Shahr bin Hawshab said:(Another chain) from Khalid bin Ziyad with similar}}
\hadithdefcmd{tirmidhi}{613}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا قَبِيصَةُ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ عَطَاءٍ الْخُرَاسَانِيِّ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ عَمَّارٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ لِلْجُنُبِ إِذَا أَرَادَ أَنْ يَأْكُلَ أَوْ يَشْرَبَ أَوْ يَنَامَ أَنْ يَتَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{613}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ammar narrated:"The Prophet permitted the Junub when he wanted to eat, drink, or sleep, to perform Wudu like the Wudu for Salat}}
\hadithdefcmd{tirmidhi}{614}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ الْقَطَوَانِيُّ الْكُوفِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا غَالِبٌ أَبُو بِشْرٍ، عَنْ أَيُّوبَ بْنِ عَائِذٍ الطَّائِيِّ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُعِيذُكَ بِاللَّهِ يَا كَعْبُ بْنَ عُجْرَةَ مِنْ أُمَرَاءَ يَكُونُونَ مِنْ بَعْدِي فَمَنْ غَشِيَ أَبْوَابَهُمْ فَصَدَّقَهُمْ فِي كَذِبِهِمْ وَأَعَانَهُمْ عَلَى ظُلْمِهِمْ فَلَيْسَ مِنِّي وَلَسْتُ مِنْهُ وَلاَ يَرِدُ عَلَىَّ الْحَوْضَ وَمَنْ غَشِيَ أَبْوَابَهُمْ أَوْ لَمْ يَغْشَ فَلَمْ يُصَدِّقْهُمْ فِي كَذِبِهِمْ وَلَمْ يُعِنْهُمْ عَلَى ظُلْمِهِمْ فَهُوَ مِنِّي وَأَنَا مِنْهُ وَسَيَرِدُ عَلَىَّ الْحَوْضَ يَا كَعْبُ بْنَ عُجْرَةَ الصَّلاَةُ بُرْهَانٌ وَالصَّوْمُ جُنَّةٌ حَصِينَةٌ وَالصَّدَقَةُ تُطْفِئُ الْخَطِيئَةَ كَمَا يُطْفِئُ الْمَاءُ النَّارَ ‏.‏ يَا كَعْبُ بْنَ عُجْرَةَ إِنَّهُ لاَ يَرْبُو لَحْمٌ نَبَتَ مِنْ سُحْتٍ إِلاَّ كَانَتِ النَّارُ أَوْلَى بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عُبَيْدِ اللَّهِ بْنِ مُوسَى ‏.‏ وَأَيُّوبُ بْنُ عَائِذٍ الطَّائِيُّ يُضَعَّفُ وَيُقَالُ كَانَ يَرَى رَأْىَ الإِرْجَاءِ ‏.‏ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَلَمْ يَعْرِفْهُ إِلاَّ مِنْ حَدِيثِ عُبَيْدِ اللَّهِ بْنِ مُوسَى وَاسْتَغْرَبَهُ جِدًّا ‏.‏\hadithno{614}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ka'b bin Ujrah narrated:"The Messenger of Allah said to me: 'I seek refuge in Allah for you O Ka'b bin Ujrah from leader that will be after me. Whoever comes to their doors to approve of their lies and supports them in their oppression, then he is not of me and I am not of him, and he will not meet me at the Hawd. And whoever comes to their doors, or he does not come, and he does not approve of their lies and he does not support them in their oppression, then he is from me and I am from him, and he will meet me at the Hawd. Ka'ab bin Ujrah! Salat is clear proof, and Sawm (fasting) is an impregnable shield, and Sadaqah (charity) extinguishes sins just as water extinguishes fire. O Ka'b bin Ujrah! There is no flesh raised that sprouts from the unlawful except that the Fire is more appropriate for it}}
\hadithdefcmd{tirmidhi}{615}{وَقَالَ مُحَمَّدٌ حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ مُوسَى، عَنْ غَالِبٍ، بِهَذَا ‏.‏\hadithno{615}\hadithgrade{Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Muhammad said:"Ibn Numair narrated to us from Ubaidullah bin Musa, from Ghalib" with this (Hadith)}}
\hadithdefcmd{tirmidhi}{616}{حَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الْكِنْدِيُّ الْكُوفِيُّ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، أَخْبَرَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، حَدَّثَنِي سُلَيْمُ بْنُ عَامِرٍ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ فِي حَجَّةِ الْوَدَاعِ فَقَالَ ‏ "‏ اتَّقُوا اللَّهَ رَبَّكُمْ وَصَلُّوا خَمْسَكُمْ وَصُومُوا شَهْرَكُمْ وَأَدُّوا زَكَاةَ أَمْوَالِكُمْ وَأَطِيعُوا ذَا أَمْرِكُمْ تَدْخُلُوا جَنَّةَ رَبِّكُمْ ‏"‏ ‏.‏ قَالَ فَقُلْتُ لأَبِي أُمَامَةَ مُنْذُ كَمْ سَمِعْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم هَذَا الْحَدِيثَ قَالَ سَمِعْتُهُ وَأَنَا ابْنُ ثَلاَثِينَ سَنَةً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{616}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sulaim bin Amir narrated:"I heard Abu Umamah saying: I heard the Messenger of Allah giving a Khutbah during the Farewell Hajj, and he said: 'Have Taqwa of your Lord, and pray your five (prayers), and fast your month, and pay the Zakat on your wealth, and obey thosewho are in charge of you, you will enter the Paradise of your Lord.'" He said: "I said to Abu Umamah: 'How old were you when you heard this Hadith (from the Messenger of Allah)?' He said: 'I heard it when I was thirty years old}}
